<?php

	class Mod_home extends CI_Model{
		
		function __construct()
		{
			parent::__construct();
			
		}
		
		function count_car(){
			return $this->db->count_all_results('tblcar');	
		}
		
		function count_location(){
			return $this->db->count_all_results('tbllocation');	
		}
		
		function count_routes(){
			return $this->db->count_all_results('tblroutes');	
		}
		
		function count_service(){
			return $this->db->count_all_results('tblservices');	
		}
		
		function count_type(){
			return $this->db->count_all_results('tbltypecar');	
		}
		
		function count_brand(){
			return $this->db->count_all_results('tblbrand');	
		}
		
		function count_price(){
			return $this->db->count_all_results('tblprice');	
		}
		
		function count_images(){
			return $this->db->count_all_results('tblimages');	
		}
		
	}