<?php 
if ( ! defined('BASEPATH')) exit('No direct script access allowed');
class Home extends Admin_Controller {
	
	   function __construct()
	   {
			parent::__construct();
			$this->load->model("mod_home");
	   }		

        public function index()
        {
			$tab['activeTab'] = "home";
			$tatal_car = $this->mod_home->count_car();
			$data['tatal_car'] = $tatal_car;
			
			$tatal_location = $this->mod_home->count_location();
			$data['tatal_location'] = $tatal_location;
			
			$tatal_routes = $this->mod_home->count_routes();
			$data['tatal_routes'] = $tatal_routes;
		
			$tatal_service = $this->mod_home->count_service();
			$data['tatal_service'] = $tatal_service;
			
			$tatal_type = $this->mod_home->count_type();
			$data['tatal_type'] = $tatal_type;
			
			$tatal_type = $this->mod_home->count_type();
			$data['tatal_type'] = $tatal_type;
			
			$tatal_brand = $this->mod_home->count_brand();
			$data['tatal_brand'] = $tatal_brand;
			
			$tatal_price = $this->mod_home->count_price();
			$data['tatal_price'] = $tatal_price;
			
			$tatal_images = $this->mod_home->count_images();
			$data['tatal_images'] = $tatal_images;
			
			
			$this->load->view('admin/header',$tab);
			$this->load->view('admin/dashboard',$data);
			$this->load->view('admin/footer');
        }
	
		
		
		
}